@@ -22,7 +22,7 @@ copyright = '2022, Ather Abbas'
 author = 'Ather Abbas, Sara Iftikhar'
 
 # The full version, including alpha/beta/rc tags
-release = "0.20"
+release = "0.20.1"
 
 
 # -- General configuration ---------------------------------------------------
